@@ -3,3 +3,14 @@ from .naive_bayes import NaiveBayes
 from .textsimilarity.compression_similarity import compression_similarity, CompressionSimilarity
 from .textsimilarity.euclidian_similarity import euclidian_similarity, EuclidianSimilarity
 from .textsimilarity.jaccard_similarity import jaccard_similarity, JaccardSimilarity
+
+__all__ = [
+    "sets",
+    "NaiveBayes",
+    "compression_similarity",
+    "CompressionSimilarity",
+    "euclidian_similarity",
+    "EuclidianSimilarity",
+    "jaccard_similarity",
+    "JaccardSimilarity"
+]
\ No newline at end of file
